@@ -10,7 +10,7 @@ Preprocessing functions- using your TERMite output to make AI-ready data
 """
 
 __author__ = 'SciBite DataScience'
-__version__ = '0.3'
+__version__ = '0.3.7'
 __copyright__ = '(c) 2019, SciBite Ltd'
 __license__ = 'Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License'
 
@@ -24,7 +24,7 @@ class DocStoreRequestBuilder():
     """
 
     def __init__(self):
-        self.url = "https://tyrion.scibite.com:9999"
+        self.url = ""
         self.input_file_path = ''
         self.payload = {"output": "json"}
         self.options = {}
@@ -46,13 +46,14 @@ class DocStoreRequestBuilder():
 
     def set_url(self, url):
         """
-        Set the URL of the DOCStore instance e.g. for local instance http://localhost:9090/termite
+        Set the URL of the DOCStore instance
         :param url: the URL of the DOCStore instance to be hit
         """
-        self.url = url
+        self.url = url.rstrip('/')
 
-    def get_dcc_docs(self, entity_list, source, options_dict):
+    def get_dcc_docs(self, entity_list, source='*', options_dict=None):
         """
+        - Document co-occurrence - 
         Retrieve document co-occurrence of provided entities
         :param entity_list: list of entities to be searched for
         :param source: name of data source(s) to be searched against
@@ -81,14 +82,17 @@ class DocStoreRequestBuilder():
         except:
             pass
 
-        response = requests.get(query_url, params=options, verify=False)
+        response = requests.get(query_url, params=options, auth=self.basic_auth)
+
         resp_json = response.json()
+        
 
         return resp_json
 
-    def get_boolean_docs(self, query_string, source, options_dict):
+    def get_boolean_docs(self, query_string, source='*', options_dict=None):
         """
-        Retrieve document co-occurrence of provided entities
+        - Document-level query of Doc Store - 
+        Document-level query of Doc Store, produced both hit and facet data
         :param query_string: query to be completed
         :param source: name of data source(s) to be searched against
         :param options_dict: search parameters
@@ -96,7 +100,6 @@ class DocStoreRequestBuilder():
         """
         base_url = self.url
         query_url = (base_url) + "/api/ds/v1/search/document/{}/*/*/*".format(source)
-
         options = {"fmt": "json",
                    "fields": "*",
                    "query": query_string,
@@ -116,14 +119,49 @@ class DocStoreRequestBuilder():
         except:
             pass
 
-        response = requests.get(query_url, params=options, verify=False)
+        response = requests.get(query_url, params=options, auth=self.basic_auth)
         resp_json = response.json()
 
         return resp_json
 
-    def get_scc_docs(self, entity_list, source, options_dict):
+    def get_docs(self, query_string, source='*', options_dict=None):
         """
-        Retrieve sentence co-occurrence of provided entities
+        - Document-level query of Doc Store, returning only the documents hit, 
+        no facet data. -
+        The output is TERMite/TEXpress ready
+        :param query_string: query to be completed
+        :param source: name of data source(s) to be searched against
+        :param options_dict: search parameters
+        :return: results of search in json format
+        """
+        base_url = self.url
+        query_url = (base_url) + '/api/ds/v1/search/document/docs/{}/*/*/*'.format(source)  
+        options = {"fields": "*",
+                   "fmt":"json",
+                   "query": query_string,
+                   "limit": "10",
+                   "from": "0",
+                   "sortby": "document_date:desc",
+                   "filters": "",
+                   "zip":"false",
+                   "metaonly":"false"
+                   }
+
+        try:
+            for k, v in options_dict.items():
+                if k in options.keys():
+                    options[k] = v
+        except:
+            pass
+
+        response = requests.get(query_url, params=options, auth=self.basic_auth)
+        resp_json = response.json()
+        return resp_json
+
+    def get_scc_docs(self, entity_list, source='*', options_dict=None):
+        """
+        - Sentence co-occurrence on entity ids or types, returns documents 
+        containing sentences fulfilling the co-occurrence. - 
         :param entity_list: list of entities to be searched for
         :param source: name of data source(s) to be searched against
         :param options_dict: search parameters
@@ -151,11 +189,53 @@ class DocStoreRequestBuilder():
         except:
             pass
 
-        response = requests.get(query_url, params=options, verify=False)  # May need to add authentication details here
+        response = requests.get(query_url, params=options, auth=self.basic_auth)
         resp_json = response.json()
 
         return resp_json
-
+    
+    def get_doc_by_id(self,doc_id, fmt='json'):
+        """Retrieves document by its unique ID"""
+        options = {"fmt": fmt,
+                   "uid":doc_id}
+        base_url = self.url
+        query_url = (base_url) + "/api/ds/v1/lookup/doc"
+        response = requests.get(query_url, params=options, auth=self.basic_auth)
+        resp_json = response.json()
+        return resp_json
+    
+    def entity_lookup_id(self, syn, entity_type, options_dict=None):
+        """Lookup IDs for a synonym and type"""
+        options = {"syn": syn,
+                   "type":entity_type}
+        base_url = self.url
+        query_url = (base_url) + "/api/entity/v1/lookup/id"
+        response = requests.get(query_url, params=options, auth=self.basic_auth)
+        resp_json = response.json()
+        return resp_json
+    def get_facets_only(self,query_string,facetFilter, source ='*', significantTerms = False, options_dict = None):
+        """Document-level query of Doc Store, returning only the facets"""
+        options ={"fmt": "json",
+                   "fields": "*",
+                   "query": query_string,
+                   "facetFilter":facetFilter,
+                   "limit": "10",
+                   "from": "0",
+                   "facettype": "BY_TYPE",
+                   "significantTerms": "false",
+                   "excludehits": "false",
+                   }
+        try:
+            for k, v in options_dict.items():
+                if k in options.keys():
+                    options[k] = v
+        except:
+            pass
+        base_url = self.url
+        query_url = (base_url) + '/api/ds/v1/search/document/facets/{}/*/*/*'.format(source)  
+        response = requests.get(query_url, params=options, auth=self.basic_auth)
+        resp_json = response.json()
+        return resp_json
 
 def get_docstore_dcc_df(json):
     """
@@ -173,10 +253,13 @@ def get_docstore_dcc_df(json):
         doc_id = h["id"]
 
         # Document date
-        doc_date = (h["documentDate"])[0:10]
-
+        doc_date = ""
+        try:
+            doc_date = h["documentDate"][0:10]
+        except:
+            pass
         # Title
-        highlighted_sections = (h['highlightedSections'])[0]
+        highlighted_sections = h['highlightedSections'][0]
         title_words = highlighted_sections['titleWords']
 
         title_list = []
@@ -195,8 +278,11 @@ def get_docstore_dcc_df(json):
             pass
 
         # Citation
-        citation = h["citation"]
-
+        citation = ""
+        try:
+            citation = h["citation"]
+        except:
+            pass
         hit_dict.update([("document_id", doc_id), ("document_date", doc_date), ("title", title),
                          ("authors", authors), ("citation", citation)])
         df_rows.append(hit_dict)
@@ -214,14 +300,18 @@ def get_docstore_scc_df(json):
     df_rows = []
     hits = json["hits"]
 
-    for h in df_rows:
+    for h in hits:
         hit_dict = {}
 
         # Document id
         doc_id = h["docId"]
 
         # Document date
-        doc_date = (h["docDate"])[0:10]
+        doc_date = ""
+        try:
+            doc_date = h["docDate"][0:10]
+        except:
+            pass
 
         # SCC Sentence
         doc_sent = h["sentence"]
@@ -231,3 +321,5 @@ def get_docstore_scc_df(json):
 
     scc_df = pd.DataFrame(df_rows, columns=["document_id", "document_date", "scc_sentence"])
     return (scc_df)
+
+
