@@ -12,7 +12,7 @@ generate insights.
 
 
 __author__ = 'SciBite AI'
-__version__ = '0.1'
+__version__ = '0.3.7'
 __copyright__ = '(c) 2020, SciBite Ltd'
 __license__ = 'Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License'
 
@@ -879,7 +879,15 @@ def get_hits(termiteTags, hierarchy=None, vocabs=None):
 			if hit['entityType'] not in vocabs:
 				continue
 
-		hitLocs, subsumeStates = hit['exact_array'], hit['subsume']
+		if 'fls' in hit['exact_array'][0]: #TERMite 6.3...
+			hitLocs, subsumeStates = hit['exact_array'], hit['subsume']
+		else: #TERMite 6.4...
+			hitLocs = []
+			subsumeStates = []
+			for hit_array in hit['exact_array']:
+				hitLocs.append({'fls': [hit_array['sentence'], hit_array['start'], hit_array['end']]})
+				subsumeStates.append(hit_array['subsumed'])
+
 		assert len(hitLocs) == len(subsumeStates)
 
 		for idx, hitLoc in enumerate(hitLocs):
@@ -1000,7 +1008,7 @@ def markup(docjsonx, normalisation='id', substitute=True, wrap=False,
 
 def text_markup(text, termiteAddr='http://localhost:9090/termite', vocabs=['GENE', 'INDICATION', 'DRUG'],
 				normalisation='id', wrap=False, wrapChars=('{!', '!}'), substitute=True, replacementDict=None,
-				termite_http_user=None, termite_http_pass=None):
+				termite_http_user=None, termite_http_pass=None, include_json=False):
 	'''
 	Receives plain text, returns text with TERMited substitutions.
 
@@ -1027,8 +1035,14 @@ def text_markup(text, termiteAddr='http://localhost:9090/termite', vocabs=['GENE
 		t.set_basic_auth(termite_http_user, termite_http_pass, verification=False)
 	docjsonx = t.execute()
 
-	return markup(docjsonx, vocabs=vocabs, normalisation=normalisation, wrap=wrap,
-				  wrapChars=wrapChars, substitute=substitute, replacementDict=replacementDict)[0]['termited_text']
+	if include_json:
+		return markup(docjsonx, vocabs=vocabs, normalisation=normalisation, wrap=wrap,
+					  wrapChars=wrapChars, substitute=substitute, 
+					  replacementDict=replacementDict)[0]['termited_text'], docjsonx
+	else:
+		return markup(docjsonx, vocabs=vocabs, normalisation=normalisation, wrap=wrap,
+					  wrapChars=wrapChars, substitute=substitute, 
+					  replacementDict=replacementDict)[0]['termited_text']
 
 
 def label(docjsonx, vocabs, labelLevel='word'):
